#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.1.0
visibility:           public
id:                   gridtables-0.1.1.0-KxFtBTWK8uF75sz6sCOYti
key:                  gridtables-0.1.1.0-KxFtBTWK8uF75sz6sCOYti
license:              MIT
copyright:            © 2022-2023 Posit Software, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  02b3ce83262fc9ea25bedc9351f8ecac
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.1.0-KxFtBTWK8uF75sz6sCOYti
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    doclayout-0.5-KjnKi2Ux4oIGbAAgAzLZAm parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

